@@ -362,56 +362,46 @@ impl Debug for World {
 
 #[cfg(test)]
 mod tests {
-    use crate::component::Component;
-    use crate::resource::Resource;
     use std::fmt::Debug;
+    use crate::component::Component;
     use crate::group::{full_owning, non_owning, partial_owning};
     use crate::query::WithId;
     use crate::world::World;
 
-    #[derive(Debug,Clone,Copy,PartialEq)]
-    struct Char(char);
-    #[derive(Debug,Clone,Copy,PartialEq)]
-    struct U32(u32);
-    #[derive(Debug,Clone,Copy,PartialEq)]
-    struct Unit;
-
-    impl Component for Char{}
-    impl Component for U32{}
-    impl Component for Unit{}
-
     #[test]
     fn component_test() {
         let mut world = World::new();
-        world.register::<Char>();
+
+        world.register::<char>();
+
         let id1 = world.create_entity().into_id();
         let id2 = world.create_entity().into_id();
         let _id3 = world.create_entity().into_id();
 
-        world.attach_component(id1,Char('c'));
-        world.attach_component(id2,Char('a'));
+        world.attach_component(id1,'c');
+        world.attach_component(id2,'a');
 
         {
-            let components = world.components_read::<Char>().unwrap();
+            let components = world.components_read::<char>().unwrap();
             let components = components.data();
-            assert_eq!(components,&[Char('c'),Char('a')])
+            assert_eq!(components,&['c','a'])
         }
         world.remove_entity(id1);
 
         {
-            let components = world.components_read::<Char>().unwrap();
+            let components = world.components_read::<char>().unwrap();
             let components = components.data();
-            assert_eq!(components,&[Char('a')])
+            assert_eq!(components,&['a'])
         }
     }
 
     #[test]
     fn group_test() {
-
         let mut world = World::new();
-        world.register::<U32>();
-        world.register::<Char>();
-        world.register::<Unit>();
+
+        world.register::<u32>();
+        world.register::<char>();
+        world.register::<()>();
 
         fn print<T>(world : &World,msg : &str)
         where T: Component + Clone + Debug {
@@ -422,56 +412,56 @@ mod tests {
             println!("{}:{:?}",msg,&v);
         }
 
-        world.create_entity().attach(U32(1)).attach(Unit);
-        let id2 = world.create_entity().attach(U32(2)).into_id();
+        world.create_entity().attach(1_u32).attach(());
+        let id2 = world.create_entity().attach(2_u32).into_id();
         let id3 = world
             .create_entity()
-            .attach(U32(3))
-            .attach(Char('a'))
-            .attach(Unit)
+            .attach(3_u32)
+            .attach('a')
+            .attach(())
             .into_id();
-        world.create_entity().attach(U32(4)).attach(Char('b'));
-        world.create_entity().attach(U32(5)).attach(Char('c'));
-        world.create_entity().attach(U32(6));
-        let id7 = world.create_entity().attach(Char('d')).attach(Unit).into_id();
+        world.create_entity().attach(4_u32).attach('b');
+        world.create_entity().attach(5_u32).attach('c');
+        world.create_entity().attach(6_u32);
+        let id7 = world.create_entity().attach('d').attach(()).into_id();
         println!("#initial");
-        print::<U32>(&world, "u32 :");
-        print::<Char>(&world, "char:");
-        print::<Unit>(&world, "()  :");
+        print::<u32>(&world, "u32 :");
+        print::<char>(&world, "char:");
+        print::<()>(&world, "()  :");
         println!();
 
         dbg!("Here");
-        world.make_group(full_owning::<U32, Char>());
+        world.make_group(full_owning::<u32, char>());
         dbg!("Here");
-        world.make_group(non_owning::<U32, Char>());
+        world.make_group(non_owning::<u32, char>());
         dbg!("Here");
-        world.make_group(partial_owning::<Unit, U32>());
+        world.make_group(partial_owning::<(), u32>());
         dbg!("Here");
         println!("#Made group full/non<u32,char> partial_owning<(),u32>");
-        print::<U32>(&world, "u32 :");
-        print::<Char>(&world, "char:");
-        print::<Unit>(&world, "()  :");
+        print::<u32>(&world, "u32 :");
+        print::<char>(&world, "char:");
+        print::<()>(&world, "()  :");
         println!();
 
-        world.attach_component(id2,Char('b'));
+        world.attach_component(id2,'b');
         println!("#attach component char b for id=2");
-        print::<U32>(&world, "u32 :");
-        print::<Char>(&world, "char:");
-        print::<Unit>(&world, "()  :");
+        print::<u32>(&world, "u32 :");
+        print::<char>(&world, "char:");
+        print::<()>(&world, "()  :");
         println!();
 
-        world.attach_component(id7,U32(2));
+        world.attach_component(id7,2_u32);
         println!("#attach component u32=2 for id=7");
-        print::<U32>(&world, "u32 :");
-        print::<Char>(&world, "char:");
-        print::<Unit>(&world, "()  :");
+        print::<u32>(&world, "u32 :");
+        print::<char>(&world, "char:");
+        print::<()>(&world, "()  :");
         println!();
 
-        world.detach_component::<U32>(id3);
+        world.detach_component::<u32>(id3);
         println!("#detach component u32 for id=3");
-        print::<U32>(&world, "u32 :");
-        print::<Char>(&world, "char:");
-        print::<Unit>(&world, "()  :");
+        print::<u32>(&world, "u32 :");
+        print::<char>(&world, "char:");
+        print::<()>(&world, "()  :");
         println!();
     }
 
@@ -479,16 +469,16 @@ mod tests {
     fn debug_trait_test() {
         let mut world = World::new();
 
-        world.register::<Char>();
-        world.register::<U32>();
+        world.register::<char>();
+        world.register::<u32>();
 
-        world.create_entity().attach(Char('c')).attach(U32(12));
-        world.create_entity().attach(Char('a'));
+        world.create_entity().attach('c').attach(12_u32);
+        world.create_entity().attach('a');
 
-        world.make_group(full_owning::<Char, U32>());
+        world.make_group(full_owning::<char, u32>());
 
-        world.create_entity().attach(Char('c')).attach(U32(12));
-        world.create_entity().attach(Char('a'));
+        world.create_entity().attach('c').attach(12_u32);
+        world.create_entity().attach('a');
 
         println!("{:?}", world);
     }
@@ -501,7 +491,6 @@ mod tests {
             name : String,
             age : u32
         }
-        impl Resource for Test {}
         
         world.register_resource(Test{
             name : "affff".to_string(),
@@ -521,25 +510,25 @@ mod tests {
     fn entity_component_test() {
         let mut world = World::new();
 
-        world.register::<U32>();
+        world.register::<u32>();
 
-        world.create_entity().attach(U32(5));
-        let id = world.create_entity().attach(U32(7)).into_id();
-        world.create_entity().attach(U32(2));
+        world.create_entity().attach(5_u32);
+        let id = world.create_entity().attach(7_u32).into_id();
+        world.create_entity().attach(2_u32);
 
         {
-            let v = world.entity_component_read::<U32>(id).unwrap();
-            assert_eq!(*v,U32(7));
+            let v = world.entity_component_read::<u32>(id).unwrap();
+            assert_eq!(*v,7);
         }
 
         {
-            let mut v = world.entity_component_write::<U32>(id).unwrap();
-            *v = U32(3);
+            let mut v = world.entity_component_write::<u32>(id).unwrap();
+            *v = 3;
         }
 
         {
-            let v = world.entity_component_read::<U32>(id).unwrap();
-            assert_eq!(*v,U32(3));
+            let v = world.entity_component_read::<u32>(id).unwrap();
+            assert_eq!(*v,3);
         }
     }
 
@@ -547,27 +536,27 @@ mod tests {
     fn entity_test() {
         let mut world = World::new();
 
-        world.register::<U32>();
+        world.register::<u32>();
 
-        world.create_entity().attach(U32(5));
-        let id = world.create_entity().attach(U32(7)).into_id();
-        world.create_entity().attach(U32(2));
+        world.create_entity().attach(5_u32);
+        let id = world.create_entity().attach(7_u32).into_id();
+        world.create_entity().attach(2_u32);
 
         let entity = world.entity(id).unwrap();
 
         {
-            let v = entity.component_read::<U32>().unwrap();
-            assert_eq!(*v,U32(7));
+            let v = entity.component_read::<u32>().unwrap();
+            assert_eq!(*v,7);
         }
 
         {
-            let mut v = entity.component_write::<U32>().unwrap();
-            *v = U32(3);
+            let mut v = entity.component_write::<u32>().unwrap();
+            *v = 3;
         }
 
         {
-            let v = entity.component_read::<U32>().unwrap();
-            assert_eq!(*v,U32(3));
+            let v = entity.component_read::<u32>().unwrap();
+            assert_eq!(*v,3);
         }
     }
 }
